@@ -4,15 +4,28 @@
     <Outputs Condition="'$(Configuration)|$(Platform)'=='Release|x64'">$(TargetDir)%(Filename).obj;$(TargetDir)%(Filename)_sse2.obj;$(TargetDir)%(Filename)_sse4.obj;$(TargetDir)%(Filename)_avx.obj;$(TargetDir)%(Filename)_avx2.obj;</Outputs>
 */
 
+use std::{fs, path::Path};
+
+fn clean_target(target_name: &str, target_arch: &str) {
+    let target_file = format!("src/ispc/lib{}{}", target_name, target_arch);
+    if Path::new(format!("src/ispc/kernel{}", target_arch).as_str()).exists() {
+        fs::remove_file(target_file).unwrap();
+    }
+}
+
 #[cfg(feature = "ispc")]
 fn compile_kernel() {
     use std::env;
 
     use ispc_compile::TargetISA;
 
+    let target_arch = env::var("CARGO_CFG_TARGET_ARCH").unwrap();
+
     println!("cargo:rerun-if-changed=src/ispc/*");
 
-    let target_arch = env::var("CARGO_CFG_TARGET_ARCH").unwrap();
+    clean_target("kernel", &target_arch);
+    clean_target("kernel_astc", &target_arch);
+
     let target_isas = match target_arch.as_str() {
         "x86" | "x86_64" => vec![
             TargetISA::SSE2i32x4,
